==> coil-0.9.4-javadoc.jar: coil-gif/coil.decode/-gif-decoder/index.md <==
[coil-gif](../../index.md) / [coil.decode](../index.md) / [GifDecoder](./index.md)

# GifDecoder

`class GifDecoder : `[`Decoder`](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decoder/index.md)

A [Decoder](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decoder/index.md) that uses [Movie](https://developer.android.com/reference/android/graphics/Movie.html) to decode GIFs.

NOTE: Prefer using [ImageDecoderDecoder](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-image-decoder-decoder/index.md) on Android P and above.

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | A [Decoder](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decoder/index.md) that uses [Movie](https://developer.android.com/reference/android/graphics/Movie.html) to decode GIFs.`GifDecoder()` |

### Functions

| Name | Summary |
|---|---|
| [decode](decode.md) | `suspend fun decode(pool: `[`BitmapPool`](file:/Users/Colin/coil/docs/api/coil-base/coil.bitmappool/-bitmap-pool/index.md)`, source: `[`BufferedSource`](https://square.github.io/okio/2.x/okio/okio/-buffered-source/index.md)`, size: `[`Size`](file:/Users/Colin/coil/docs/api/coil-base/coil.size/-size/index.md)`, options: `[`Options`](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-options/index.md)`): `[`DecodeResult`](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decode-result/index.md) |
| [handles](handles.md) | `fun handles(source: `[`BufferedSource`](https://square.github.io/okio/2.x/okio/okio/-buffered-source/index.md)`, mimeType: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |

### Companion Object Properties

| Name | Summary |
|---|---|
| [REPEAT_COUNT_KEY](-r-e-p-e-a-t_-c-o-u-n-t_-k-e-y.md) | `const val REPEAT_COUNT_KEY: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |

==> coil-0.11.0-javadoc.jar: coil-gif/coil.decode/-gif-decoder/index.md <==
[coil-gif](../../index.md) / [coil.decode](../index.md) / [GifDecoder](./index.md)

# GifDecoder

`class GifDecoder : `[`Decoder`](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decoder/index.md)

A [Decoder](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decoder/index.md) that uses [Movie](https://developer.android.com/reference/android/graphics/Movie.html) to decode GIFs.

NOTE: Prefer using [ImageDecoderDecoder](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-image-decoder-decoder/index.md) on API 28 and above.

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | A [Decoder](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decoder/index.md) that uses [Movie](https://developer.android.com/reference/android/graphics/Movie.html) to decode GIFs.`GifDecoder()` |

### Functions

| Name | Summary |
|---|---|
| [decode](decode.md) | `suspend fun decode(pool: `[`BitmapPool`](file:/Users/Colin/coil/docs/api/coil-base/coil.bitmappool/-bitmap-pool/index.md)`, source: `[`BufferedSource`](https://square.github.io/okio/2.x/okio/okio/-buffered-source/index.md)`, size: `[`Size`](file:/Users/Colin/coil/docs/api/coil-base/coil.size/-size/index.md)`, options: `[`Options`](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-options/index.md)`): `[`DecodeResult`](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decode-result/index.md) |
| [handles](handles.md) | `fun handles(source: `[`BufferedSource`](https://square.github.io/okio/2.x/okio/okio/-buffered-source/index.md)`, mimeType: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |

### Companion Object Properties

| Name | Summary |
|---|---|
| [REPEAT_COUNT_KEY](-r-e-p-e-a-t_-c-o-u-n-t_-k-e-y.md) | `const val REPEAT_COUNT_KEY: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
